Django-Weeny
============

Simple URL shortener app for Django.

Features
--------

#. Content-Types based wiring, meaning you can hook a short URL to any object
   in your database.
#. URL tracking. Control URL tracking per-site or per-URL. Collects extensive
   User Agent information which gives a good base for collecting statistics.
#. Password protection on single URL's.
#. Absolutely no tests whatsoever. <self sarcasm>This code is completely untestet,
   which is a major selling point!</self sarcasm>


Documentation
-------------

Read the full documentation `here <http://django-weeny.readthedocs.org/en/latest/>`_
